@@ -70,6 +70,10 @@ def handle_input_data(request):
             request.server.logger.error('after_request_func_list raise exception. func: %s, view_func_result: %s, e: %s, traceback: %s',
                                         func.__name__, view_func_result, e, __import__('traceback').format_exc())
 
+    if view_func_result is None:
+        # 如果是None，就代表不想返回数据
+        return view_func_result
+
     if isinstance(view_func_result, dict):
         view_func_result = request.server.make_rsp(**view_func_result)
 
@@ -146,7 +150,8 @@ class GourdSyncTcpRequestHandler(SocketServer.StreamRequestHandler):
 
         result = handle_input_data(self)
 
-        self.wfile.write(result)
+        if result is not None:
+            self.wfile.write(result)
         # 因为wfile的bufsize设置为0了，所以不需要flush也可以
         # self.wfile.flush()
         # handle结束后socket会自己调用关闭，并且关闭也会发送数据，因为tcp是半双工的
@@ -219,7 +224,8 @@ class GourdSyncUdpRequestHandler(SocketServer.BaseRequestHandler):
 
         result = handle_input_data(self)
 
-        self.socket.sendto(result, self.client_address)
+        if result is not None:
+            self.socket.sendto(result, self.client_address)
 
     def finish(self):
         # teardown_request_func_list
